const Meta = imports.gi.Meta;
const Mainloop = imports.mainloop;

let display;
let workspaceManager;

function moveWindowToNewWorkspace(window) {
    try {
        if (window.get_window_type() !== Meta.WindowType.NORMAL) return;

        // Create new workspace
        const newWorkspace = workspaceManager.append_new_workspace(false, global.get_current_time());

        // Move window before it appears
        window.change_workspace(newWorkspace);
        newWorkspace.activate_with_focus(window, global.get_current_time());

        // Prevent duplicate handling
        window.auto_moved = true;
    } catch(e) {
        logError(e, 'Failed to move window');
    }
}

function onWindowCreated(display, window) {
    // Universal handling for both X11 and Wayland
    if (window.auto_moved) return;

    // Use simple timeout for universal compatibility
    Mainloop.timeout_add(50, () => {
        if (!window.auto_moved && window.get_compositor_private()) {
            moveWindowToNewWorkspace(window);
        }
        return false; // Remove timeout
    });
}

function enable() {
    display = global.display;
    workspaceManager = global.workspace_manager;
    display.connect('window-created', onWindowCreated);
}

function disable() {
    display.disconnect('window-created', onWindowCreated);
    display = null;
    workspaceManager = null;
}
